<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="姓名" prop="name">
        <el-input
          v-model="queryParams.name"
          placeholder="请输入姓名"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="手机号" prop="phone">
        <el-input
          v-model="queryParams.phone"
          placeholder="请输入手机号"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="身份证号" prop="identity">
        <el-input
          v-model="queryParams.identity"
          placeholder="请输入身份证号"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="状态" prop="state">
        <el-select v-model="queryParams.state" placeholder="请选择状态" clearable>
          <el-option
            v-for="dict in dict.type.jx_report_state"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item label="是否面签" prop="isSign">
        <el-select v-model="queryParams.isSign" placeholder="请选择状态" clearable>
          <el-option
            v-for="dict in dict.type.sign_status"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>

      <el-form-item label="是否退学" prop="isReturn">
        <el-select v-model="queryParams.isReturn" placeholder="请选择状态" clearable>
          <el-option
            v-for="dict in dict.type.school_return"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>

        <el-form-item label="课程名称" prop="courseName">
          <el-input
            v-model="queryParams.courseName"
            placeholder="请输入课程名称"
            clearable
            @keyup.enter.native="handleQuery"
          />
        </el-form-item>
      </el-form-item>
<!--      <el-form-item label="是否下午" prop="afternoon">-->
<!--        <el-input-->
<!--          v-model="queryParams.afternoon"-->
<!--          placeholder="请输入是否下午"-->
<!--          clearable-->
<!--          @keyup.enter.native="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
        >删除</el-button>
      </el-col>

      <el-col :span="1.5">
        <el-button
          type="info"
          plain
          icon="el-icon-upload2"
          size="mini"
          @click="handleImport"
        >导入
        </el-button>
      </el-col>

      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['system:pay:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="payList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
<!--      <el-table-column label="类别" align="center" prop="typeDec" />-->
      <el-table-column label="序号" align="center" prop="sorNumber" />
      <el-table-column label="姓名" align="center" prop="name" />
      <el-table-column label="手机号" align="center" prop="phone" />
      <el-table-column label="学员照片" align="center" prop="proofTwo" width="100">
        <template slot-scope="scope">
          <image-preview :src="scope.row.proofTwo" :width="50" :height="50"/>
        </template>
      </el-table-column>
      <el-table-column label="缴费金额" align="center" prop="money" />
<!--      <el-table-column label="家庭住址" align="center" prop="address" />
      <el-table-column label="缴费情况" align="center" prop="moneyDetail" />
      <el-table-column label="黑谷录入" align="center" prop="blackInto" />
      <el-table-column label="管理费" align="center" prop="manageMoney" />
      <el-table-column label="科二结款" align="center" prop="towMoney" />
      <el-table-column label="科三结款" align="center" prop="thirdMoney" />
      <el-table-column label="科二考试日期" align="center" prop="twoTime" />
      <el-table-column label="科二结款日期" align="center" prop="twoMoneyTime" />
      <el-table-column label="科三考试日期" align="center" prop="thirdTime" />
      <el-table-column label="科三结款日期" align="center" prop="thirdMoneyTime" />
      <el-table-column label="结款教练" align="center" prop="coursenName" />-->
<!--      <el-table-column label="身份证" align="center" prop="identity" />-->
<!--      <el-table-column label="身份证" align="center" prop="identity" />-->
      <el-table-column label="状态" align="center" prop="state">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.jx_report_state" :value="scope.row.state"/>
        </template>
      </el-table-column>
      <el-table-column label="职业" align="center" prop="prof">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.profession" :value="scope.row.prof"/>
        </template>
      </el-table-column>
<!--      <el-table-column label="是否面签" align="center" prop="isSign">-->
<!--        <template slot-scope="scope">-->
<!--          <dict-tag :options="dict.type.sign_status" :value="scope.row.isSign"/>-->
<!--        </template>-->
<!--      </el-table-column>-->
      <el-table-column label="课程名称" align="center" prop="courseName" />
<!--      <el-table-column label="支付方式" align="center" prop="startPay" >-->
      <el-table-column label="报名日期" align="center" prop="createTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.createTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>

<!--      <el-table-column label="退学日期" align="center" prop="endTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.endTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>-->
      <el-table-column label="退费金额" align="center" prop="returnMoney" />

<!--      <el-table-column label="转账凭证" align="center" prop="proofOne" width="100">
        <template slot-scope="scope">
          <image-preview :src="scope.row.proofOne" :width="50" :height="50"/>
        </template>
      </el-table-column>-->
      <el-table-column label="身份证号" align="center" prop="identity" />

      <el-table-column label="教练" align="center"  >
        <template #default="data">
          <el-button @click="changeJlClick(data.row.jxId, data.row.id)" size="mini" v-if="!data.row.jlName" type="primary">分配教练</el-button>
          <div style="color: #00afff" @click="changeJlClick(data.row.jxId, data.row.id)" v-else>{{data.row.jlName}}</div>
        </template>
      </el-table-column>
      <el-table-column label="备注" align="center" prop="remark" />
<!--      <el-table-column label="是否下午" align="center" prop="afternoon" />-->
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template #default="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改订单对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="750px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="120px">
        <el-form-item label="姓名" prop="name">
          <el-input v-model="form.name" placeholder="请输入姓名" />
        </el-form-item>
        <el-form-item label="手机号" prop="phone">
          <el-input v-model="form.phone" placeholder="请输入手机号" />
        </el-form-item>
        <el-form-item label="学员照片" prop="proofTwo">
          <image-upload limit="1" v-model="form.proofTwo"/>
        </el-form-item>
        <el-form-item label="职业" prop="prof">
          <el-radio-group v-model="form.prof">
            <el-radio
              v-for="dict in dict.type.profession"
              :key="dict.value"
              :label="dict.value"
            >{{dict.label}}</el-radio>
          </el-radio-group>
        </el-form-item>
        <el-form-item label="状态" prop="state">
          <el-radio-group v-model="form.state">
            <el-radio
              v-for="dict in dict.type.jx_report_state"
              :key="dict.value"
              :label="parseInt(dict.value)"
            >{{dict.label}}</el-radio>
          </el-radio-group>
        </el-form-item>
        <el-form-item label="是否已面签" prop="isSign">
          <el-radio-group v-model="form.isSign">
            <el-radio
              v-for="dict in dict.type.sign_status"
              :key="dict.value"
              :label="parseInt(dict.value)"
            >{{dict.label}}</el-radio>
          </el-radio-group>
        </el-form-item>
        <el-form-item label="是否退学" prop="isReturn">
          <el-radio-group v-model="form.isReturn">
            <el-radio
              v-for="dict in dict.type.school_return"
              :key="dict.value"
              :label="dict.value"
            >{{dict.label}}</el-radio>
          </el-radio-group>
        </el-form-item>
<!--        <el-form-item label="支付方式" prop="startPay">
          <el-input v-model="form.startPay" placeholder="请输入支付方式" />
        </el-form-item>-->
<!--        <el-form-item label="订单编号" prop="orderNumber">
          <el-input v-model="form.orderNumber" placeholder="请输入订单编号" />
        </el-form-item>-->

        <el-form-item label="退费金额（元）" prop="returnMoney">
          <el-input v-model="form.returnMoney" placeholder="请输入退费金额" />
        </el-form-item>
        <el-form-item label="转账凭证" prop="proofOne">
          <image-upload limit="1" v-model="form.proofOne"/>
        </el-form-item>

<!--        <el-form-item label="是否下午" prop="afternoon">-->
<!--          <el-input v-model="form.afternoon" placeholder="请输入是否下午" />-->
<!--        </el-form-item>-->
      </el-form>
      <el-form-item label="身份证号" prop="identity">
        <el-input v-model="form.identity" placeholder="请输入身份证号" />
      </el-form-item>
      <el-form-item label="备注" prop="remark">
        <el-input v-model="form.remark" placeholder="请输入备注" />
      </el-form-item>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>

    <!--  修改教练 -->
    <el-dialog
      :visible.sync="isJl"
      width="30%"
      >


      <el-table v-loading="loading" :data="jlListAll" @selection-change="handleSelectionChange">

        <el-table-column label="教练姓名" align="center" prop="instructorName" />
        <el-table-column label="手机号" align="center" prop="phone" />

        <el-table-column label="操作"  align="center" class-name="small-padding fixed-width">
          <template #default="scope">
            <el-button
              size="mini"
              type="text"
              icon="el-icon-edit"
              @click="okJlClick(scope.row.instructorName, scope.row.id)"
            >选择</el-button>

          </template>
        </el-table-column>
      </el-table>

      <span slot="footer" class="dialog-footer">
    <el-button @click="exitJlClick()">取 消</el-button>
  </span>
    </el-dialog>

    <el-dialog :title="upload.title" :visible.sync="upload.open" width="400px" append-to-body>
      <el-upload
        ref="upload"
        :limit="1"
        accept=".xlsx, .xls"
        :headers="upload.headers"
        :action="upload.url + '?updateSupport=' + upload.updateSupport"
        :disabled="upload.isUploading"
        :on-progress="handleFileUploadProgress"
        :on-success="handleFileSuccess"
        :auto-upload="false"
        drag
      >
        <i class="el-icon-upload"></i>
        <div class="el-upload__text">将文件拖到此处，或<em>点击上传</em></div>
        <div class="el-upload__tip text-center" slot="tip">
<!--          <div class="el-upload__tip" slot="tip">
            <el-checkbox v-model="upload.updateSupport"/>
            是否更新已经存在的用户数据
          </div>-->
          <span>仅允许导入xls、xlsx格式文件。</span>
<!--          <el-link type="primary" :underline="false" style="font-size:12px;vertical-align: baseline;"
                   @click="importTemplate">下载模板
          </el-link>-->
        </div>
      </el-upload>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitFileForm">确 定</el-button>
        <el-button @click="upload.open = false">取 消</el-button>
      </div>
    </el-dialog>


  </div>
</template>

<script>
// import { listPay, getPay, delPay, addPay, updatePay } from "@/api/system/pay";
import { listPay, getPay, delPay, addPay, updatePay, findJlListAll, updatePayById } from "./api/DriveSchoolPay";
import {getToken} from "@/utils/auth";

export default {
  name: "Pay",
  dicts: ['jx_report_state','sign_status','school_return','profession'],
  data() {
    return {

      // 用户导入参数
      upload: {
        // 是否显示弹出层（用户导入）
        open: false,
        // 弹出层标题（用户导入）
        title: "",
        // 是否禁用上传
        isUploading: false,
        // 是否更新已经存在的用户数据
        updateSupport: 0,
        // 设置上传的请求头部
        headers: {Authorization: "Bearer " + getToken()},
        // 上传的地址
        url: process.env.VUE_APP_BASE_API + "/system/pay/importData"
      },

      isJl: false,

      jlListAll: [],

      bmId: null,

      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 订单表格数据
      payList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        name: null,
        phone: null,
        identity: null,
        state: null,
        startPay: null,
        createTime: null,
        orderNumber: null,
        afternoon: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        name: [
          { required: true, message: "姓名不能为空", trigger: "blur" }
        ],
        phone: [
          { required: true, message: "手机号不能为空", trigger: "blur" }
        ],
        state: [
          { required: true, message: "状态不能为空", trigger: "change" }
        ],
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    // 提交上传文件
    submitFileForm() {
      this.$refs.upload.submit();
    },

    /** 导入按钮操作 */
    handleImport() {
      this.upload.title = "学员导入";
      this.upload.open = true;
    },


    exitJlClick() {
      this.isJl = false
    },
    async okJlClick(name, id) {
      await updatePayById(this.bmId, name, id)
      this.isJl = false

      listPay(this.queryParams).then(response => {
        this.payList = response.data.records;
        this.total = response.data.total;
        this.loading = false;
      });

    },
    async changeJlClick(jlId, bmId) {
      this.isJl = true
      let res = await findJlListAll(jlId);
      this.jlListAll = res
      this.bmId = bmId
    },
    /** 查询订单列表 */
    getList() {
      this.loading = true;
      listPay(this.queryParams).then(response => {
        this.payList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        name: null,
        phone: null,
        identity: null,
        state: null,
        userId: null,
        jlId: null,
        jxId: null,
        courseId: null,
        startPay: null,
        createTime: null,
        orderNumber: null,
        afternoon: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加订单";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getPay(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改订单";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updatePay(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addPay(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除订单编号为"' + ids + '"的数据项？').then(function() {
        return delPay(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('system/pay/export', {
        ...this.queryParams
      }, `pay_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
